==> morphcp-0.0.1.tar.gz: morphcp-0.0.1/morphcp/vars.py <==
# Base Tenant Role Name
base_tenant_role_name = "BaseTenantRole"
multi_tenant_role_name = "MultiTenantRole"
# Tenant Admin User
tenant_admin_user_name = "TenantAdmin"
tenant_admin_password = "Morpheus321!"

# hotshot_user_password = "SelfS3rv!ceOrchestration-4theWin!"

# url specific
max_results = 1000


########################################
###### CONTENT PACK COMPONENTS #########
########################################
# Content Pack base folder
contentpack_base_folder = "contentpacks"

# Group Variables
groups_inject_filter_pattern = "*group_output_extract*"
groups_payload_folder = "group_payload"
groups_extract_filename = "group_output_extract"

# Role Variables
roles_inject_filter_pattern = "*manifest*"
roles_payload_folder = "role_payload"
roles_extract_filename = "role_output_list"


# User Variables
user_inject_filter_pattern = "*user_name*"
user_payload_folder = "user_payload"
user_extract_filename = "user_output_extract"

# Task Variables
task_inject_filter_pattern = "*task_name*"
task_payload_folder = "task_payload"
task_extract_filename = "task_output_extract"

# Option List Variables
optionlist_inject_filter_pattern = "*optionlist_name*"
optionlist_payload_folder = "optionlist_payload"
optionlist_extract_filename = "optionlist_output_extract"

# Input Variables
input_inject_filter_pattern = "*input_name*"
input_payload_folder = "input_payload"
input_extract_filename = "input_output_extract"

# Workflow Variables
workflow_inject_filter_pattern = "*workflow_name*"
workflow_payload_folder = "workflow_payload"
workflow_extract_filename = "workflow_output_extract"

# Policy Variables
policy_inject_filter_pattern = "*policy_name*"
policy_payload_folder = "policy_payload"
policy_extract_filename = "policy_output_extract"

# Whitelabel Variables
whitelabel_inject_filter_pattern = "*whitelabel_settings*"
whitelabel_payload_folder = "whitelabel_payload"
whitelabel_extract_filename = "whitelabel_output_extract"


# Catalog Variables
catalog_inject_filter_pattern = "*catalog_item*"
catalog_payload_folder = "catalog_payload"
catalog_extract_filename = "catalog_output_extract"

# Cloud Variables
cloud_pattern = "*cloud*"
cloud_payload_folder = "cloud_payload"

==> morphcp-0.0.2.tar.gz: morphcp-0.0.2/morphcp/vars.py <==
# Base Tenant Role Name
base_tenant_role_name = "BaseTenantRole"
multi_tenant_role_name = "MultiTenantRole"
# Tenant Admin User
tenant_admin_user_name = "TenantAdmin"
tenant_admin_password = "Morpheus321!"

# hotshot_user_password = "SelfS3rv!ceOrchestration-4theWin!"

# url specific
max_results = 1000


########################################
###### CONTENT PACK COMPONENTS #########
########################################
# Content Pack base folder
contentpack_base_folder = "morph_contentpack/contentpacks"

# Group Variables
groups_inject_filter_pattern = "*group_output_extract*"
groups_payload_folder = "group_payload"
groups_extract_filename = "group_output_extract"

# Role Variables
roles_inject_filter_pattern = "*manifest*"
roles_payload_folder = "role_payload"
roles_extract_filename = "role_output_list"


# User Variables
user_inject_filter_pattern = "*user_name*"
user_payload_folder = "user_payload"
user_extract_filename = "user_output_extract"

# Task Variables
task_inject_filter_pattern = "*task_name*"
task_payload_folder = "task_payload"
task_extract_filename = "task_output_extract"

# Option List Variables
optionlist_inject_filter_pattern = "*optionlist_name*"
optionlist_payload_folder = "optionlist_payload"
optionlist_extract_filename = "optionlist_output_extract"

# Input Variables
input_inject_filter_pattern = "*input_name*"
input_payload_folder = "input_payload"
input_extract_filename = "input_output_extract"

# Workflow Variables
workflow_inject_filter_pattern = "*workflow_name*"
workflow_payload_folder = "workflow_payload"
workflow_extract_filename = "workflow_output_extract"

# Policy Variables
policy_inject_filter_pattern = "*policy_name*"
policy_payload_folder = "policy_payload"
policy_extract_filename = "policy_output_extract"

# Whitelabel Variables
whitelabel_inject_filter_pattern = "*whitelabel_settings*"
whitelabel_payload_folder = "whitelabel_payload"
whitelabel_extract_filename = "whitelabel_output_extract"


# Catalog Variables
catalog_inject_filter_pattern = "*catalog_item*"
catalog_payload_folder = "catalog_payload"
catalog_extract_filename = "catalog_output_extract"

# Cloud Variables
cloud_pattern = "*cloud*"
cloud_payload_folder = "cloud_payload"
